# vim: set sw=4 ts=4 et:
#
# spec file for package aircrack-ng
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without unstable
%bcond_without sqlite
%define pkg_version 1.2-rc2

Name:           aircrack-ng
Version:        1.2.rc2
Release:        1.1
License:        GPL-2.0
Summary:        A set of tools for auditing wireless networks
Url:            http://www.aircrack-ng.org/
Group:          Productivity/Networking/Security
Source0:        http://download.aircrack-ng.org/%{name}-%{pkg_version}.tar.gz
Source1:        README.SUSE
BuildRequires:  gcc-c++
BuildRequires:	libgcrypt-devel
%if 0%{?suse_version} <= 1140
BuildRequires:  libnl-devel
%else
BuildRequires:	libnl3-devel
%endif
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:	sqlite3-devel
BuildRequires:	zlib-devel
Requires:	    wireless-tools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Aircrack-ng is an 802.11 WEP and WPA-PSK keys cracking program that
can recover keys once enough data packets have been captured.
It implements the standard FMS attack along with some optimizations
like KoreK attacks, as well as the PTW attack, thus making the attack
much faster compared to other WEP cracking tools.

In fact, Aircrack-ng is a set of tools for auditing wireless networks.

%prep
%setup -q -n aircrack-ng-%{pkg_version}
find patches/ -type f -exec sed -i 's|\r||g' {} \;
cp "%{SOURCE1}" .

%build
CFLAGS="%{optflags} -Wall" \
make \
        %{?_smp_mflags} \
        SQLITE=%{?with_sqlite:true}%{?!with_sqlite:false} \
        EXPERIMENTAL=%{?with_unstable:true}%{?!with_unstable:false} \
	    gcrypt=true \
	    libnl=true \
        prefix="%{_prefix}" \
        libdir="%{_libdir}" \
        docdir="%{_docdir}/%{name}"

%install
%makeinstall \
        SQLITE=%{?with_sqlite:true}%{?!with_sqlite:false} \
        EXPERIMENTAL=%{?with_unstable:true}%{?!with_unstable:false} \
        ext_scripts=true \
	    gcrypt=true \
	    libnl=true \
        sbindir="%{_sbindir}" \
        bindir="%{_bindir}" \
	    smandir="%{_mandir}/man8" \
        mandir="%{_mandir}/man1" \
        libdir="%{_libdir}" \
        docdir="%{_docdir}/%{name}" \
        localedir="/usr/share/locale" \
        DESTDIR="%{buildroot}"

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog LICENSE LICENSE.OpenSSL README README.SUSE
%doc patches
%{_bindir}/aircrack-ng
%{_bindir}/airdecap-ng
%{_bindir}/airdecloak-ng
%{_bindir}/ivstools
%{_bindir}/kstats
%{_bindir}/makeivs-ng
%{_bindir}/packetforge-ng
%{_bindir}/wpaclean
%{_bindir}/versuck-ng
%{_sbindir}/airbase-ng
%{_sbindir}/aireplay-ng
%{_sbindir}/airmon-ng
%{_sbindir}/airodump-ng
%{_sbindir}/airodump-ng-oui-update
%{_sbindir}/airserv-ng
%{_sbindir}/airtun-ng
%{_sbindir}/besside-ng
%if %{with sqlite}
%{_bindir}/airolib-ng
%endif
%if %{with unstable}
%{_bindir}/buddy-ng
%{_sbindir}/easside-ng
%{_sbindir}/tkiptun-ng
%{_sbindir}/wesside-ng
%endif
%doc %{_mandir}/man1/*.1%{ext_man}
%doc %{_mandir}/man8/*.8%{ext_man}

%changelog
* Sat Jun  6 2015 mailaender@opensuse.org
- update to 1.2-rc2
  * Airtun-ng: Adds WPA CCMP and TKIP decryption and CCMP encryption
  * Compilation: Added support for DUMA.
  * Makefile: Renamed 'unstable' to 'experimental'.
  * Airodump-ng: Fixed XML sanitizing.
  * Airmon-ng: Airmon-zc is now stable enough to replace airmon-ng.
  * Manpages: Removed airdriver-ng manpage and references to it (forgot to do it before the previous release).
  * Manpages: Updated 'see also' references in all manpages.
  * PCRE: Added it in various places and docs.
  * WZCook: Fixed processing values stored in register.
  * Updated a few headers files (if_llc, ieee80211, ethernet and if_arp).
  * Compilation: de-hardcode -lpcap to allow specifying pcap libraries.
  * Makefile: Fixed installing/uninstalling Airdrop-ng documentation files.
  * Makefile: Fixed uninstalling ext_scripts.
  * Airodump-ng: Added new paths (and removed one) for OUI files and simplified logic to find the OUI file.
  * Aircrack-ng: Fixed ignoring -p when specified after -S.
  * Airmon-ng: fixes for openwrt busybox ps/grep issues which do not seem present in other versions of busybox
  * Airmon-ng: fix vm detection.
  * Airserv-ng: Fixed channel setting (and assert call).
  * Airodump-ng: Fixes to NetXML (unassociated clients missing and various other small bugs) and update the code to match current NetXML output.
  * Airodump-ng: Removed requirement for 2 packets before AP is written to output (text) files.
  * Airodump-ng: Fixed formatting of ESSID and display of WPA/WPA2 (as well as a bunch of other small fixes) in CSV file.
  * Airodump-ng: Fixed GPSd.
  * Airodump-ng: Allow to specify write interval for CSV, kismet CSV and NetXML files.
  * Airserv-ng: Fixed wrong station data displayed in Airodump-ng.
  * General: Fixed 64 bit promotion issues.
  * General: Fixed a bunch of uninitialized values and non-zeroed structures (upon allocating them).
  * General: Added Stack protection.
  * Various other small fixes and improvements
* Thu Nov 13 2014 p.seiler@linuxmail.org
- update to 1.2-rc1
  * Airodump-ng should be able to parse the canonical oui file.
  * Airodump-ng: Fixed GPS stack overflow.
  * Airodump-ng: Fixed stopping cleanly with Ctrl-C.
  * Airmon-zc: better handling for when modules are not available (incomplete)
  * Airmon-zc: users can now start the monitor interface again to change channels
  * Airmon-zc: update to use ip instead of ifconfig if available.
  * Airmon-zc: better handling of devices without pci bus
  * Aireplay-ng: Fixed tcp_test stack overflow.
  * OSdep: Fixed libnl detection. Also avoid detection on non Linux systems.
  * OSdep: Fixed segmentation fault that happens with a malicious server.
  * Besside-ng: Add regular expression matching for the SSID.
  * Buddy-ng: Fixed segmentation fault.
  * Makefile: Fixed 'commands commence before first target' error when building Aircrack-ng.
  * Fixed segfault when changing the optimization when compiling with gcc thanks to Ramiro Polla.
  * Removed airdriver-ng (outdated and not meant for today's kernels)
  * Added gitignore file.
  * Fixed build issues on other compilers by using stdint.h types.
  * Updating installation file and added pkg-config as a requirement.
  * Various small fixes and improvements.
* Sun Jan 12 2014 chris@computersalat.de
- update to 1.2-beta2
  * Airbase-ng: Fixed order of IE when creating soft Access Point.
  * Airbase-ng: Fixed Caffe Latte Attack not working for all clients.
  * Aircrack-ng: Improved PTW speed thanks to Ramiro Polla.
  * Airmon-zc: Fixed improper use of the interface.
  * Airdecap-ng: Fixed decoding captures with WMM enabled.
  * Various: Fixed memory leaks in Aircrack-ng, Aireplay-ng, OSdep.
  * Added support for static analysis using Coverity Scan.
  * Fixed compilation due to PIC unfriendly assembly on Gentoo hardened.
  * Fixed running tests using 'make check'.
  * Fixed building aircrack-ng with recent version of gcc and also on cygwin.
  * Various other small fixes.
* Sat Aug 31 2013 i@margueirte.su
- update version 1.2-beta1
  * see http://www.aircrack-ng.org/doku.php?id=changelog for details
- enable:
  * gcrypt: Use libgcrypt crypto library instead of the default OpenSSL
    And also use internal fast sha1 implementation
  * libnl: Add support for netlink (nl80211)
  * ext_scripts: airoscript-ng, versuck-ng, airgraph-ng and airdrop-ng
* Sun Apr 25 2010 pascal.bleser@opensuse.org
- update to 1.1
* Fri Oct 23 2009 pascal.bleser@opensuse.org
- forced rebuild to avoid uploading the binary packages
* Tue Sep  8 2009 pascal.bleser@opensuse.org
- update to 1.0
* Thu Sep  3 2009 pascal.bleser@opensuse.org
- update to rc4
* Thu Apr 16 2009 pascal.bleser@opensuse.org
- changed version to include rc3, final will be 1.0+final
- pass %%%%optflags properly
- spec file cleanup
- update to rc3
* Thu Jul 17 2008 andrea@links2linux.de
- First spec Making
